@@ -19,9 +19,8 @@
 #define REDDIT_GOSUB_H 1
 
 #include <config.h>
-#include <stdio.h>
 #include <argp.h>
-#include "reddit_priv.h"
+#include "reddit.h"
 
 struct reddit_gosub_options_t
 {
