@@ -28,8 +28,7 @@ enum app_command_line_options_t
   OPT_HOST = 'h',
   OPT_LOGIN = 'l',
   OPT_QUIET = 'q',
-  OPT_SCRIPT = 's',
-  OPT_PASSWORD_WALLET = 'w',
+  OPT_REDDIT = 'r',
 };
 
 struct arguments_t 
