@@ -253,7 +253,7 @@ reddit_parse_command (struct reddit_state_t *state, char *line, int *quit)
     {
     case HISTORY:
       if (!value)
-        err = reddit_history (state);
+        err = reddit_history (state, NULL);
       else
         err = reddit_set_history (state, value);
       break;
@@ -500,6 +500,32 @@ myreadline (char *prompt)
 }
 #endif
 
+        
+static int 
+reddit_batch (struct reddit_state_t *state, struct reddit_options_t *arguments)
+{
+  int err = 0;
+  int quit = 0;
+  char *line = NULL;
+  size_t len = 0;
+  ssize_t read;
+  FILE *fileptr = fopen (arguments->script, "r");
+  if (!fileptr)
+    return -1;
+  while ((read = getline (&line, &len, fileptr)) != -1)
+    {
+      err = reddit_parse_untrimmed_command (state, line, &quit);
+
+      if (quit)
+        break;
+      if (err)
+	break;
+    }
+  free (line);
+  fclose (fileptr);
+  return err;
+}
+
 static int
 reddit_interactive (struct reddit_state_t *state, struct reddit_options_t *arguments)
 {
@@ -514,7 +540,7 @@ reddit_interactive (struct reddit_state_t *state, struct reddit_options_t *argum
 #ifdef HAVE_LIBREADLINE
       line = readline (REDDIT_PROMPT);
       if (line)
-	add_history (line);
+        add_history (line);
       rl_get_screen_size (NULL, &state->columns);
 #else
       line = myreadline (REDDIT_PROMPT);
@@ -576,7 +602,11 @@ reddit (struct reddit_options_t *arguments)
   int err = 0;
 
   memset (&state, 0, sizeof (state));
-  state.wallet = arguments->wallet;
+  state.script = arguments->script;
+  char *wallet = getenv ("REDDIT_WALLET");
+  if (wallet && atoi (wallet) == 1)
+    state.wallet = xasprintf("%s/.%s-wallet", getenv("HOME"), PACKAGE);
+
   state.links_binary = g_find_program_in_path ("links");
   if (state.links_binary == NULL)
     {
@@ -598,7 +628,7 @@ reddit (struct reddit_options_t *arguments)
     state.site = strdup (arguments->host);
 
   if (arguments->cookie_file == NULL)
-    arguments->cookie_file= REDDIT_COOKIEJAR;
+    arguments->cookie_file = REDDIT_COOKIEJAR;
 
   state.banner = arguments->banner;
   state.page_size = 2;
@@ -627,9 +657,14 @@ reddit (struct reddit_options_t *arguments)
     }
 
 #ifdef HAVE_LIBREADLINE
-  rl_initialize ();
-  rl_reset_screen_size ();
-  rl_get_screen_size (NULL, &state.columns);
+  if (state.script == 0)
+    {
+      rl_initialize ();
+      rl_reset_screen_size ();
+      rl_get_screen_size (NULL, &state.columns);
+    }
+  else
+    state.silent = 1;
 #endif
 
   state.logged_in = 
@@ -643,7 +678,12 @@ reddit (struct reddit_options_t *arguments)
                                   NULL, NULL);
 
   if (!err)
-    err = reddit_interactive (&state, arguments);
+    {
+      if (arguments->script == NULL)
+        err = reddit_interactive (&state, arguments);
+      else
+        err = reddit_batch (&state, arguments);
+    }
   curl_easy_cleanup(state.curl);
   curl_global_cleanup();
   free (state.username);
@@ -652,7 +692,7 @@ reddit (struct reddit_options_t *arguments)
   free (state.browser_options);
   free (state.openssl_binary);
   free (state.reddits);
+  free (state.wallet);
   free (state.site);
-  free (arguments->wallet);
   return err;
 }
