@@ -29,11 +29,11 @@ struct reddit_options_t
   char *subreddit;
   char *proxy;
   int proxy_port;
-  char *wallet;
   char *host;
   int no_initial_stories;
   char *cookie_file;
   int banner;
+  char *script;
 };
 
 struct reddit_state_t
@@ -63,13 +63,14 @@ struct reddit_state_t
   int page_size; //how many stories per page.
   char *search; //current search terms.
   int banner; //whether or not to show the bottom banner.
+  char *script;
 };
 
 //the main loop
 int reddit (struct reddit_options_t *opts);
 
 //the non-argp commands
-int reddit_history(struct reddit_state_t *state);
+int reddit_history(struct reddit_state_t *state, int *val);
 int reddit_set_banner(struct reddit_state_t *state, char *value);
 int reddit_warranty (struct reddit_state_t *state);
 int reddit_browser (struct reddit_state_t *state);
