@@ -143,8 +143,6 @@ reddit_load_stories_from_data (struct reddit_state_t *state, char *data, size_t
   if (num_stories > 1)
     {
       *stories = malloc (sizeof (struct reddit_story_t ) * (num_stories - 1));
-      if (state->logged_in)
-        reddit_get_modhash_from_chunk (state, fields[0]);
       if (*stories)
         {
           gchar **ptr = &fields[1];
@@ -161,6 +159,8 @@ reddit_load_stories_from_data (struct reddit_state_t *state, char *data, size_t
                 i++;
             }
           num_stories = i;
+          if (state->logged_in)
+            reddit_get_modhash_from_chunk (state, fields[0]);
         }
       else
         num_stories = 0;
@@ -172,7 +172,7 @@ reddit_load_stories_from_data (struct reddit_state_t *state, char *data, size_t
   return num_stories;
 }
 
-static int 
+int 
 reddit_load_stories_from_file (struct reddit_state_t *state, FILE *fileptr, struct reddit_story_t **stories)
 {
   if (!fileptr)
@@ -193,7 +193,10 @@ reddit_load_stories (struct reddit_state_t *state, char *url, struct reddit_stor
   int fd = mkstemp(tmp);
   close (fd);
   FILE *fileptr = fopen (tmp, "wb");
+  curl_easy_setopt (state->curl, CURLOPT_HTTPGET, 1);
   curl_easy_setopt (state->curl, CURLOPT_URL, url);
+  //curl_easy_setopt (state->curl, CURLOPT_POSTFIELDS, 0);
+  //curl_easy_setopt (state->curl, CURLOPT_POSTFIELDSIZE, 0);
   curl_easy_setopt (state->curl, CURLOPT_WRITEDATA, fileptr);
   curl_easy_perform(state->curl);
   fflush (fileptr);
