@@ -149,6 +149,13 @@ reddit_load_link_from_story_chunk (struct reddit_state_t *state, gchar *data)
           return NULL;
         }
       state->logged_in = !state->logged_in;
+      if (state->logged_in == 0)
+        {
+          free (state->username);
+          state->username = NULL;
+          free (state->modhash);
+          state->modhash = NULL;
+        }
     }
 
   int retval = sscanf (fields[1], "%ms", &link);
