@@ -20,6 +20,7 @@
 #include <glib.h>
 #include <argz.h>
 #include <string.h>
+#include "xvasprintf.h"
 #include "reddit_priv.h"
 #include "view.h"
 #include "story.h"
@@ -130,7 +131,15 @@ reddit_spawn_viewer_for_link (struct reddit_state_t *state, char *link)
 static int
 spawn_viewer_for_story (struct reddit_state_t *state, struct reddit_story_t *story)
 {
-  return reddit_spawn_viewer_for_link (state, story->link);
+  if (strncmp (story->link, "/r/", 3) == 0)
+    {
+      char *link = xasprintf ("http://%s/%s.compact", state->site, story->link);
+      int err = reddit_spawn_viewer_for_link (state, link);
+      free (link);
+      return err;
+    }
+  else
+    return reddit_spawn_viewer_for_link (state, story->link);
 }
 
 int 
