@@ -73,7 +73,7 @@ reddit_get_stats_from_data (struct reddit_state_t *state, char *data, int *link_
   return 0;
 }
 
-static int
+int
 reddit_get_stats_from_file (struct reddit_state_t *state, FILE *fileptr, 
                             int *link_karma, int *comment_karma, char **age)
 {
@@ -95,7 +95,10 @@ reddit_get_stats (struct reddit_state_t *state, char *link, int *link_karma, int
   int fd = mkstemp(tmp);
   close (fd);
   FILE *fileptr = fopen (tmp, "wb");
+  curl_easy_setopt (state->curl, CURLOPT_HTTPGET, 1);
   curl_easy_setopt (state->curl, CURLOPT_URL, link);
+  //curl_easy_setopt (state->curl, CURLOPT_POSTFIELDS, 0);
+  //curl_easy_setopt (state->curl, CURLOPT_POSTFIELDSIZE, 0);
   curl_easy_setopt (state->curl, CURLOPT_WRITEDATA, fileptr);
   curl_easy_perform(state->curl);
   fflush (fileptr);
@@ -141,11 +144,10 @@ reddit_whoami(struct reddit_state_t *state)
     }
   else
     {
-      reddintf (state, "%s\n", state->username);
-      reddintf (state, _("Link Karma: %d\n"), link_karma);
-      reddintf (state, _("Comment Karma: %d\n"), comment_karma);
-      reddintf (state, "%s\n", age);
-      reddintf (state, "\n");
+      fprintf (state->out, "%s\n", state->username);
+      fprintf (state->out, _("Link Karma: %d\n"), link_karma);
+      fprintf (state->out, _("Comment Karma: %d\n"), comment_karma);
+      fprintf (state->out, "%s\n", age);
     }
   free (age);
   return err;
